@@ -656,7 +656,7 @@ class Image(object):
         if len(geometry) == 4:
             width, height = geometry[0], geometry[1]
             x, y = geometry[2], geometry[3]
-            g = pgmagick.Geometry(x, y, width, height)
+            g = pgmagick.Geometry(width, height, x, y)
         elif len(geometry) == 1 and isinstance(geometry[0], pgmagick.Geometry):
             g = geometry[0]
         else:
