@@ -24,7 +24,7 @@ void __QuantumType()
         .value("RGBQuantum", Magick::RGBQuantum)
         .value("RGBAQuantum", Magick::RGBAQuantum)
         .value("CMYKQuantum", Magick::CMYKQuantum)
-#ifndef GM_1_1_x
+#ifdef PGMAGICK_LIB_GRAPHICSMAGICK_1_3_x
         .value("CIEYQuantum", Magick::CIEYQuantum)
         .value("CIEXYZQuantum", Magick::CIEXYZQuantum)
 #endif
